@@ -134,7 +134,7 @@ class AttributeUniquenessPlugin(Plugin):
         'nsslapd-pluginDescription': 'Enforce unique attribute values',
     }
 
-    def __init__(self, instance, dn="cn=attribute uniqueness,cn=plugins,cn=config"):
+    def __init__(self, instance, dn):
         super(AttributeUniquenessPlugin, self).__init__(instance, dn)
         self._protected = False
         self._create_objectclasses = ['top', 'nsslapdplugin', 'extensibleObject']
@@ -192,13 +192,13 @@ class AttributeUniquenessPlugins(DSLdapObjects):
         self._basedn = basedn
         # This is used to allow entry to instance to work
         self._list_attrlist = ['dn', 'nsslapd-pluginPath']
-        self._search_filter = "(nsslapd-pluginId=NSUniqueAttr)"
+        self._search_filter = "(nsslapd-pluginInitfunc=NSUniqueAttr_Init)"
         self._scope = ldap.SCOPE_SUBTREE
         self._server_controls = None
         self._client_controls = None
 
     def list(self):
-        """Get a list of all plugin instances where nsslapd-pluginId: NSUniqueAttr
+        """Get a list of all plugin instances where nsslapd-pluginInitfunc: NSUniqueAttr_Init
 
         :returns: A list of children entries
         """
@@ -206,7 +206,7 @@ class AttributeUniquenessPlugins(DSLdapObjects):
         try:
             results = self._instance.search_ext_s(
                 base=self._basedn,
-                scope=ldap.SCOPE_ONELEVEL,
+                scope=self._scope,
                 filterstr=self._search_filter,
                 attrlist=self._list_attrlist,
                 serverctrls=self._server_controls, clientctrls=self._client_controls
@@ -431,7 +431,6 @@ class ReferentialIntegrityPlugin(Plugin):
             'referint-logfile',
             'referint-membership-attr',
         ])
-        self._lint_functions = [self._lint_update_delay, self._lint_attr_indexes]
 
     def create(self, rdn=None, properties=None, basedn=None):
         """Create an instance of the plugin"""
@@ -443,6 +442,10 @@ class ReferentialIntegrityPlugin(Plugin):
             properties['referint-logfile'] = referint_log
         return super(ReferentialIntegrityPlugin, self).create(rdn, properties, basedn)
 
+    @classmethod
+    def lint_uid(cls):
+        return 'refint'
+
     def _lint_update_delay(self):
         if self.status():
             delay = self.get_attr_val_int("referint-update-delay")
@@ -455,10 +458,19 @@ class ReferentialIntegrityPlugin(Plugin):
         if self.status():
             from lib389.backend import Backends
             backends = Backends(self._instance).list()
+            attrs = self.get_attr_vals_utf8_l("referint-membership-attr")
+            container = self.get_attr_val_utf8_l("nsslapd-plugincontainerscope")
             for backend in backends:
-                indexes = backend.get_indexes()
                 suffix = backend.get_attr_val_utf8_l('nsslapd-suffix')
-                attrs = self.get_attr_vals_utf8_l("referint-membership-attr")
+                if suffix == "cn=changelog":
+                    # Always skip retro changelog
+                    continue
+                if container is not None:
+                    # Check if this backend is in the scope
+                    if not container.endswith(suffix):
+                        # skip this backend that is not in the scope
+                        continue
+                indexes = backend.get_indexes()
                 for attr in attrs:
                     report = copy.deepcopy(DSRILE0002)
                     try:
@@ -1074,24 +1086,6 @@ class AutoMembershipPlugin(Plugin):
         return task
 
 
-class AutoMembershipRegexRule(DSLdapObject):
-    def __init__(self, instance, dn=None):
-        super(AutoMembershipRegexRule, self).__init__(instance, dn)
-        self._rdn_attribute = 'cn'
-        self._must_attributes = ['cn', 'autoMemberTargetGroup']
-        self._create_objectclasses = ['top', 'autoMemberRegexRule']
-        self._protected = False
-
-
-class AutoMembershipRegexRules(DSLdapObjects):
-    def __init__(self, instance, basedn="cn=Auto Membership Plugin,cn=plugins,cn=config"):
-        super(AutoMembershipRegexRules, self).__init__(instance)
-        self._objectclasses = ['top', 'autoMemberRegexRule']
-        self._filterattrs = ['cn']
-        self._childobject = AutoMembershipRegexRule
-        self._basedn = basedn
-
-
 class AutoMembershipDefinition(DSLdapObject):
     """A single instance of Auto Membership Plugin config entry
 
@@ -1716,7 +1710,7 @@ class RootDNAccessControlPlugin(Plugin):
     def get_allow_ip(self):
         """Get rootdn-allow-ip attribute"""
 
-        return self.get_attr_val_utf8('rootdn-allow-ip')
+        return self.get_attr_vals_utf8('rootdn-allow-ip')
 
     def get_allow_ip_formatted(self):
         """Display rootdn-allow-ip attribute"""
@@ -1741,7 +1735,7 @@ class RootDNAccessControlPlugin(Plugin):
     def get_deny_ip(self):
         """Remove all rootdn-deny-ip attribute"""
 
-        return self.get_attr_val_utf8('rootdn-deny-ip')
+        return self.get_attr_vals_utf8('rootdn-deny-ip')
 
     def get_deny_ip_formatted(self):
         """Display rootdn-deny-ip attribute"""
@@ -2234,3 +2228,48 @@ class BitwisePlugin(Plugin):
 
     def __init__(self, instance, dn="cn=Bitwise Plugin,cn=plugins,cn=config"):
         super(BitwisePlugin, self).__init__(instance, dn)
+
+
+class EntryUUIDPlugin(Plugin):
+    """The EntryUUID plugin configuration
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param dn: Entry DN
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn="cn=entryuuid,cn=plugins,cn=config"):
+        super(EntryUUIDPlugin, self).__init__(instance, dn)
+
+    def fixup(self, basedn, _filter=None):
+        """Create an entryuuid fixup task
+
+        :param basedn: Basedn to fix up
+        :type basedn: str
+        :param _filter: a filter for entries to fix up
+        :type _filter: str
+
+        :returns: an instance of Task(DSLdapObject)
+        """
+
+        task = tasks.EntryUUIDFixupTask(self._instance)
+        task_properties = {'basedn': basedn}
+        if _filter is not None:
+            task_properties['filter'] = _filter
+        task.create(properties=task_properties)
+
+        return task
+
+class ContentSyncPlugin(Plugin):
+    """A single instance of Content Sync (aka syncrepl) plugin entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param dn: Entry DN
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn="cn=Content Synchronization,cn=plugins,cn=config"):
+        super(ContentSyncPlugin, self).__init__(instance, dn)
+
